This directory save the pre-defined worker to solve the sub-tasks. Each worker is defined based on the LangGraph. Each worker is defined in a separate file. The worker is defined as a class that inherits from the worker abstract class. The worker has a method called "execute" that returns the final output value of this worker and will be used by orchestrator. 
The worker will integrate tools provided by LangChain and LlamaIndex.